clear all;
close all;

% Construct decision tree using simulations
totalData = combineData(linspace(1,100));
cd ../Code;
tree = decisionTree(totalData);

% Load arduino
a = arduino;

% Prepare variables for data collection
volt = zeros(1e2,1);
t = zeros(5,1);
ii=0;
numSecondsToRun = 28800; % Initially set to run continuously for 8 hours
predictions = [];

% Begin loop to run data collection
for i=1:numSecondsToRun

%     This while loop runs until one second of data is collected
tic
while toc < 1
    ii = ii + 1;
    % Read current voltage value
    v = readVoltage(a,'A0');
    
    volt(ii)=v;

    % Get time since starting
    t(ii) = toc;
end

% Data is stored in the relevant variables
volt=volt(1:ii);
t=t(1:ii);

% Variables are prepared to pass into processing function, prepToPredict
samplingRate = 82;
dyThreshold = .5;
processedData = [];

% Ensure that at least 8 seconds of data has been collected (to ensure that
% there is a few seconds to remove initial motion artifact)
if i>=8
    
%     Save the data to a .mat file to allow for realtime processing
    voltSub = volt((i-7)*samplingRate:(i-1)*samplingRate);
    save('ECGdata.mat', 'voltSub');
     
%     Load the necessary variables and pass into the prepToPredict function
%     for processing (compute heart rate/HRV)
    loadedVariables = load('ECGdata.mat');
    loadedVolt = loadedVariables.voltSub;
    processedData = [processedData;prepToPredict(loadedVolt, samplingRate, dyThreshold)];
    
%     Make a prediction using the trained classification tree and print the
%     prediction as well as heart rate/HRV to the screen
    newPrediction = predict(tree,processedData(end,2:3))
    rate = processedData(2)
    HRV = processedData(3)
    
%     Plot the user's current ECG
    plot(linspace(0,length(loadedVolt)/82,length(loadedVolt)),loadedVolt)
    axis([0 5 0 4]);
    xlabel('Time (s)');
    ylabel('Voltage (mV)');
    title('ECG Data Collected Via Arduino');
    drawnow
    
%     Update the list of prediction and alert the user if there have been
%     at least 3 consecutive 1s or -1s
    predictions = [predictions;newPrediction];
    if length(predictions)>2
        lastThree = predictions(end-2:end);
        if lastThree(1)==1 && lastThree(2)==1 && lastThree(3)==1
%             msgbox('Pre-ictal!');
            beep
        end
        if lastThree(1)==-1 && lastThree(2)==-1 && lastThree(3)==-1
%             msgbox('Ictal!');
            beep
        end
    end
end
end

