function data = processEKGData(data, sampleRate, preIctalStart, seizureStart, seizureStop,dyThreshold)
%     Define length of window to be 5 seconds
    lengthOfWindow = 5;

    dy=diff(data)*sampleRate;   % Take the derivative of the EKG
    numSeconds=length(data)/sampleRate; % Compute the total number of seconds in the data
    
%     Iterate over the entire data sample
    for ii=1:(numSeconds-(lengthOfWindow+1))
        
        % Define the window of data and find all peaks that surpass the
        % provided threshold with the restriction that no two peaks can
        % occur closer than 0.25 seconds to one another to prevent the same
        % peaks from being identified twice
        window=dy((1+sampleRate*ii):(sampleRate*(ii+lengthOfWindow))); 
        [beats locs]=findpeaks(window,sampleRate,'MinPeakHeight',dyThreshold,'MinPeakDistance',.25);
        
%         Obtain amplitude information
        amplitudes = data(round(locs*sampleRate + ii*sampleRate));
        avgAmplitude(ii) = mean(amplitudes);
        
%         Compute mean heart rate
        timeBetweenBeats=diff(locs);
        avgTime=mean(timeBetweenBeats);
        rate(ii)=60/avgTime;
        
%         Compute heart rate variability for the window
        RRDiffs=diff(locs);
        for jj=1:length(RRDiffs)
            sqdDiffs(jj)=RRDiffs(jj)^2;
        end
        variability(ii)=sqrt(mean(sqdDiffs))*1000;
    end 
    
%     Prepare the data to be returned in a table form with labels assigned
    sampleNames=1:length(rate);
    labels=createLabels(preIctalStart,seizureStart,seizureStop,rate);
    headers={'Time' 'labels' 'rate' 'HRV' 'avgAmp'};
    unprocessedData=[sampleNames;labels(1:length(rate));rate;variability;avgAmplitude]';
    data = unprocessedData;
    data = removeArtifacts(unprocessedData);
end

% Function that assigns 0, -1, or 1 labels to each sample based on the
% provided start/stop times of the seizure
function labels = createLabels(preIctalStart,seizureStart,seizureStop, rate)
    labels = zeros(1,length(rate));
    labels(preIctalStart:seizureStart) = -1;
    labels(seizureStart:seizureStop) = 1;
end

% Remove Nan values and windows with a computed heart rate greater than 200
% (which is most likely motion artifact)
function processedData = removeArtifacts(unprocessedData)
    toRemoveRate = unprocessedData(:,3)>200;
    toRemoveNan = isnan(unprocessedData(:,3));
%     toRemoveAmp = unprocessedData(:,5)>300;
    toRemove = toRemoveRate | toRemoveNan;
    unprocessedData(toRemove,:) = [];
    processedData = unprocessedData;
end